import requests
import json

FORECAST_URI = "http://apiadvisor.climatempo.com.br/api/v1/forecast/locale/{0}/days/15?token={1}"
CURRENT_URI =  "http://apiadvisor.climatempo.com.br/api/v1/weather/locale/{0}/current?token={1}"

class Climatempo():

    def __init__(self, api_key, city):
        self._api_key = api_key
        self._city = city
        
    def get_current_status(self):
        return json.loads(requests.get(CURRENT_URI.format(self._city,self._api_key)).text)

    def get_forecast(self):
        return json.loads(requests.get(FORECAST_URI.format(self._city, self._api_key)).text)
        



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="climatempo",
    version="0.0.1",
    author="Julio Manuel Blanco Perez",
    author_email="jblancoperez@gmail.com",
    description="Simple wrapper for climatempo API (just to abstract home assistant)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jblancoperez/climatempo",
    install_requires = ['requests==2.21.0'],
    packages=['climatempo'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

